django-etc documentation
========================
https://github.com/idlesign/django-etc



Description
-----------

*Tiny stuff for Django that won't fit into separate apps.*


.. note::

    Add the **etc** application to INSTALLED_APPS in your settings file (usually 'settings.py').



Requirements
------------

1. Python 3.6+
2. Django 2.0+



Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    models
    admin
    forms
    utils
    thirdparty



Get involved into django-etc
----------------------------

**Submit issues.** If you spotted something weird in application behavior or want to propose
a feature you can do that at https://github.com/idlesign/django-etc/issues

**Write code.** If you are eager to participate in application development,
fork it at https://github.com/idlesign/django-etc, write your code, whether it should be a bugfix or a feature
implementation, and make a pull request right from the forked project page.

**Spread the word.** If you have some tips and tricks or any other words in mind that you think
might be of interest for the others — publish it.
